
# Slot: explore_weight


Weight on the probability of visiting a neighbor node to the one we're coming from in the random walk Having this higher tends the walks to be more like a Depth-First Search. Having this very high makes search more outward. Having this very low makes search very local. Equal to the inverse of q in the Node2Vec paper.

URI: [https://w3id.org/neat/nodeEmbeddingsParams__explore_weight](https://w3id.org/neat/nodeEmbeddingsParams__explore_weight)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Float](types/Float.md)

## Parents


## Children


## Used by

 * [NodeEmbeddingsParams](NodeEmbeddingsParams.md)
